#!/bin/sh
#----------------------------------------------------------------------------------------
# /var/install/config.d/postgresql.sh - configuration generator script for PostgreSQL
#
# Copyright (c) 2004 Frank Meyer <frank(at)eisfair(dot)org>
#
# Creation:     30.07.2004  fm
# Last Update:  $Id: postgresql.sh 24335 2010-06-03 00:27:43Z dv $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------------------

#------------------------------------------------------------------------------
# include eisfair script library and configuration
#------------------------------------------------------------------------------

package='postgresql84'

. /var/install/include/eislib
. /etc/config.d/${package}

crontab_path="/var/cron/etc/root"
crontab_file=${crontab_path}/${package}
spacestr="                                                            "
inst_base='/usr/lib/pgsql'
inst_dir='/usr/lib/pgsql/84'
data_dir='/var/lib/pgsql84'

# -----------------------------------------------------------------------------
# add cron job for Backup
# -----------------------------------------------------------------------------
add_cron_job ()
{
    if [ ! -d $crontab_path ]
    then
        mkdir -p $crontab_path
    fi

    # write cron file
    (
        echo "# =============================================================="
        echo "# PostgreSQL cron backup"
        echo "# Do not edit this file, edit postgresql configuraton unsing"
        echo "# eisfair configuration tools"
        echo "# Creation: `date +"%d.%m.%Y %H:%M:%S"`"
        echo "# =============================================================="
        echo "$POSTGRESQL84_BACKUP_SCHEDULE /var/install/bin/${package}-tools-backup -auto"
        echo ""
    ) > $crontab_file
    # update crontab file
    /var/install/config.d/cron >/dev/null 2>&1
}

# -----------------------------------------------------------------------------
# delete cron job
# -----------------------------------------------------------------------------
delete_cron_job () {
    # check for crontab file
    if [ -f $crontab_file ]
    then
        # delete existing file
        rm -f $crontab_file
        # update crontab file
        /var/install/config.d/cron >/dev/null 2>&1
    fi
}


#------------------------------------------------------------------------------
# Write a value into a field with a specified width
# $1 value
# $2 length of field
#------------------------------------------------------------------------------

printfield ()
{
    value=$1
    fieldwidth=$2

    if [ -z "$value" ]
    then
        echo -n "${spacestr:0:$fieldwidth}"
    else
        vallen=${#value}
        strlen=`expr $fieldwidth - $vallen`
        if [ "$strlen" -lt "1" ]
        then
            strlen="1"
        fi
        echo -n "$value${spacestr:0:$strlen}"
    fi
}


#------------------------------------------------------------------------------
# Write host access table
#------------------------------------------------------------------------------

write_hba_conf ()
{
    # write file
    {
        echo "#----------------------------------------------------------------------------"
        echo "# PostgreSQL Client Authentication Configuration File"
        echo "# generated by /var/install/config.d/${package}.sh"
        echo "#"
        echo "# Creation date: `date`"
        echo "#----------------------------------------------------------------------------"
        echo ""
        echo "# TYPE  DATABASE    USER        CIDR-ADDRESS          METHOD"

        idx=1
        while [ "$idx" -le "$POSTGRESQL84_HOST_N" ]
        do
            eval type='$POSTGRESQL84_HOST_'$idx'_TYPE'
            eval network='$POSTGRESQL84_HOST_'$idx'_NETWORK'
            eval userauth='$POSTGRESQL84_HOST_'$idx'_USERAUTH'
            eval database='$POSTGRESQL84_HOST_'$idx'_DATABASE'
            eval user='$POSTGRESQL84_HOST_'$idx'_USER'

            printfield "$type" 8
            printfield "$database" 12
            printfield "$user" 12
            printfield "$network" 22

            case "$userauth" in
            ident)
                printfield "$userauth sameuser" 1
                ;;
            pam)
                printfield "$userauth postgresql" 1
                ;;
            *)
                printfield "$userauth" 1
                ;;
            esac
            echo ""

            idx=`/usr/bin/expr $idx + 1`
	done
    } > ${data_dir}/pg_hba.conf
    chown postgres.postgres ${data_dir}/pg_hba.conf
    chmod 600 ${data_dir}/pg_hba.conf
}


#------------------------------------------------------------------------------
# Write configuration file
#------------------------------------------------------------------------------

write_postgresql_conf()
{
    # write file
    {
        echo "#----------------------------------------------------------------------------"
        echo "# PostgreSQL configuration file"
        echo "# generated by /var/install/config.d/postgresql.sh"
        echo "#"
        echo "# Creation date: `date`"
        echo "#----------------------------------------------------------------------------"
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# FILE LOCATIONS"
        echo "#---------------------------------------------------------------------------"
        echo ""
        echo "#data_directory = 'ConfigDir'           # use data in another directory"
        echo "                                        # (change requires restart)"
        echo "#hba_file = 'ConfigDir/pg_hba.conf'     # host-based authentication file"
        echo "                                        # (change requires restart)"
        echo "#ident_file = 'ConfigDir/pg_ident.conf' # ident configuration file"
        echo "                                        # (change requires restart)"
        echo ""
        echo "# If external_pid_file is not explicitly set, no extra PID file is written."
        echo "external_pid_file = '${data_dir}/postmaster.pid'"
        echo "                                        # write an extra PID file"
        echo "                                        # (change requires restart)"
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# CONNECTIONS AND AUTHENTICATION"
        echo "#---------------------------------------------------------------------------"
        echo ""
        echo "# - Connection Settings -"
        echo ""
        if [ "$POSTGRESQL84_NETWORKING" = "yes" ]
        then
            echo "listen_addresses = '*'               # what IP address(es) to listen on;"
            echo "                                     # comma-separated list of addresses;"
            echo "                                     # defaults to 'localhost', '*' = all"
            echo "                                     # (change requires restart)"
        else
            echo "listen_addresses = 'localhost'       # what IP address(es) to listen on;"
            echo "                                     # comma-separated list of addresses;"
            echo "                                     # defaults to 'localhost', '*' = all"
            echo "                                     # (change requires restart)"
        fi
        echo "port = $POSTGRESQL84_SERVER_PORT              # (change requires restart)"
        echo "max_connections = $POSTGRESQL84_MAX_CONNECTS  # (change requires restart)"
        echo "# Note: increasing max_connections costs ~400 bytes of shared memory per"
        echo "# connection slot, plus lock space (see max_locks_per_transaction)."
        echo "#superuser_reserved_connections = 3     # (change requires restart)"
        echo "#unix_socket_directory = ''             # (change requires restart)"
        echo "#unix_socket_group = ''                 # (change requires restart)"
        echo "#unix_socket_permissions = 0777         # octal"
        echo "                                        # (change requires restart)"
        echo "#bonjour_name = ''                      # defaults to the computer name"
        echo "                                        # (change requires restart)"
        echo ""
        echo "# - Security & Authentication -"
        echo ""
        echo "#authentication_timeout = 1min          # 1s-600s"
        echo "#ssl = off                              # (change requires restart)"
        echo "#ssl_ciphers = 'ALL:!ADH:!LOW:!EXP:!MD5:@STRENGTH'      # allowed SSL ciphers"
        echo "                                        # (change requires restart)"
        echo "#ssl_renegotiation_limit = 512MB        # amount of data between renegotiations"
        echo "#password_encryption = on"
        echo "#db_user_namespace = off"
        echo ""
        echo "# Kerberos"
        echo "#krb_server_keyfile = ''"
        echo "#krb_srvname = 'postgres'               # (Kerberos only)"
        echo "#krb_caseins_users = off"
        echo ""
        echo "# - TCP Keepalives -"
        echo "# see 'man 7 tcp' for details"
        echo ""
        echo "#tcp_keepalives_idle = 0                # TCP_KEEPIDLE, in seconds;"
        echo "                                        # 0 selects the system default"
        echo "#tcp_keepalives_interval = 0            # TCP_KEEPINTVL, in seconds;"
        echo "                                        # 0 selects the system default"
        echo "#tcp_keepalives_count = 0               # TCP_KEEPCNT;"
        echo "                                        # 0 selects the system default"
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# RESOURCE USAGE (except WAL)"
        echo "#---------------------------------------------------------------------------"
        echo ""
        echo "# - Memory -"
        echo ""

        if [ "$POSTGRESQL84_RESOURCE_TUNING" == "yes" ]
        then
            echo "shared_buffers = ${POSTGRESQL84_SHARED_MEM}"
            echo "temp_buffers = ${POSTGRESQL84_TEMP_MEM}"
            echo "max_prepared_transactions = $POSTGRESQL84_PREP_TRANSACTIONS"
            echo "work_mem = ${POSTGRESQL84_WORK_MEM}"
            echo "maintenance_work_mem = ${POSTGRESQL84_MAINTAIN_MEM}"
        else
            echo "shared_buffers = 16MB                   # min 128kB or max_connections*16kB"
            echo "                                        # (change requires restart)"
            echo "#temp_buffers = 8MB                     # min 800kB"
            echo "#max_prepared_transactions = 5          # can be 0 or more"
            echo "                                        # (change requires restart)"
            echo "#work_mem = 1MB                         # min 64kB"
            echo "maintenance_work_mem = 8MB              # min 1MB"
        fi

        echo "#max_stack_depth = 2MB                  # min 100kB"
        echo ""
        echo "# - Kernel Resource Usage -"
        echo ""
        echo "#max_files_per_process = 1000           # min 25"
        echo "                                        # (change requires restart)"
        echo "#shared_preload_libraries = ''          # (change requires restart)"
        echo ""
        echo "# - Cost-Based Vacuum Delay -"
        echo ""
        echo "#vacuum_cost_delay = 0                  # 0-1000 milliseconds"
        echo "#vacuum_cost_page_hit = 1               # 0-10000 credits"
        echo "#vacuum_cost_page_miss = 10             # 0-10000 credits"
        echo "#vacuum_cost_page_dirty = 20            # 0-10000 credits"
        echo "#vacuum_cost_limit = 200                # 0-10000 credits"
        echo ""
        echo "# - Background writer -"
        echo ""
        echo "#bgwriter_delay = 200ms                 # 10-10000ms between rounds"
        echo "#bgwriter_lru_maxpages = 100            # 0-1000 max buffers written/round"
        echo "#bgwriter_lru_multiplier = 2.0          # 0-10.0 multipler on buffers scanned/round"
        echo ""
        echo "# - Asynchronous Behavior -"
        echo ""
        echo "#effective_io_concurrency = 1           # 1-1000. 0 disables prefetching"
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# WRITE AHEAD LOG"
        echo "#---------------------------------------------------------------------------"
        echo ""
        echo "# - Settings -"
        echo ""

        if [ "$POSTGRESQL84_WAL_TUNING" == "yes" ]
        then
            if [ "$POSTGRESQL84_FSYNC" == "yes" ]
            then
                echo "fsync = on                                           # turns forced synchronization on or off"
            else
                echo "fsync = off                                          # turns forced synchronization on or off"
            fi
            echo "#synchronous_commit = on                # immediate fsync at commit"
            echo "wal_sync_method = $POSTGRESQL84_SYNC_METHOD"
            echo "#full_page_writes = on"
            echo "wal_buffers = ${POSTGRESQL84_WAL_DATA_MEM}"
            echo "#wal_writer_delay = 200ms               # 1-10000 milliseconds"
            echo "commit_delay = ${POSTGRESQL84_COMMIT_DELAY}"
            echo "commit_siblings = ${POSTGRESQL84_COMMIT_SIBLINGS}"
            echo ""
            echo "# - Checkpoints -"
            echo ""
            echo "checkpoint_segments = ${POSTGRESQL84_CHECKPOINT_SECTIONS}"
            echo "checkpoint_timeout = ${POSTGRESQL84_CHECKPOINT_TIMEOUT}s"
            echo "#checkpoint_completion_target = 0.5     # checkpoint target duration, 0.0 - 1.0"
            echo "checkpoint_warning = ${POSTGRESQL84_CHECKPOINT_WARNING}s"
        else
            echo "#fsync = on                             # turns forced synchronization on or off"
            echo "#synchronous_commit = on                # immediate fsync at commit"
            echo "#wal_sync_method = fsync                # the default is the first option"
            echo "#full_page_writes = on                  # recover from partial page writes"
            echo "#wal_buffers = 64kB                     # min 32kB"
            echo "#wal_writer_delay = 200ms               # 1-10000 milliseconds"
            echo "#commit_delay = 0                       # range 0-100000, in microseconds"
            echo "#commit_siblings = 5                    # range 1-1000"
            echo ""
            echo "# - Checkpoints -"
            echo ""
            echo "#checkpoint_segments = 3                # in logfile segments, min 1, 16MB each"
            echo "#checkpoint_timeout = 5min              # range 30s-1h"
            echo "#checkpoint_completion_target = 0.5     # checkpoint target duration, 0.0 - 1.0"
            echo "#checkpoint_warning = 30s               # 0 is off"
        fi

        echo ""
        echo "# - Archiving -"
        echo ""
        echo "#archive_mode = off             # allows archiving to be done"
        echo "                                # (change requires restart)"
        echo "#archive_command = ''           # command to use to archive a logfile"
        echo "                                # segment"
        echo "#archive_timeout = 0            # force a logfile segment switch after this"
        echo "                                # many seconds; 0 is off"
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# QUERY TUNING"
        echo "#---------------------------------------------------------------------------"
        echo ""
        echo "# - Planner Method Configuration -"
        echo ""
        echo "#enable_bitmapscan = on"
        echo "#enable_hashagg = on"
        echo "#enable_hashjoin = on"
        echo "#enable_indexscan = on"
        echo "#enable_mergejoin = on"
        echo "#enable_nestloop = on"
        echo "#enable_seqscan = on"
        echo "#enable_sort = on"
        echo "#enable_tidscan = on"
        echo ""
        echo "# - Planner Cost Constants -"
        echo ""
        echo "#seq_page_cost = 1.0                    # measured on an arbitrary scale"
        echo "#random_page_cost = 4.0                 # same scale as above"
        echo "#cpu_tuple_cost = 0.01                  # same scale as above"
        echo "#cpu_index_tuple_cost = 0.005           # same scale as above"
        echo "#cpu_operator_cost = 0.0025             # same scale as above"
        echo "#effective_cache_size = 128MB"
        echo ""
        echo "# - Genetic Query Optimizer -"
        echo ""
        echo "#geqo = on"
        echo "#geqo_threshold = 12"
        echo "#geqo_effort = 5                        # range 1-10"
        echo "#geqo_pool_size = 0                     # selects default based on effort"
        echo "#geqo_generations = 0                   # selects default based on effort"
        echo "#geqo_selection_bias = 2.0              # range 1.5-2.0"
        echo ""
        echo "# - Other Planner Options -"
        echo ""
        echo "#default_statistics_target = 10         # range 1-1000"
        echo "#constraint_exclusion = off"
        echo "#cursor_tuple_fraction = 0.1            # range 0.0-1.0"
        echo "#from_collapse_limit = 8"
        echo "#join_collapse_limit = 8                # 1 disables collapsing of explicit"
        echo "                                        # JOINs"
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# ERROR REPORTING AND LOGGING"
        echo "#---------------------------------------------------------------------------"
        echo ""
        echo "# - Where to Log -"
        echo ""
        echo "log_destination = 'stderr'              # Valid values are combinations of"
        echo "                                        # stderr, syslog and eventlog,"
        echo "                                        # depending on platform."
        echo ""
        echo "# This is used when logging to stderr:"
        echo "logging_collector = on                  # Enable capturing of stderr into log"
        echo "                                        # files"
        echo ""
        echo "# These are only used if redirect_stderr is on:"
        echo "log_directory = '${data_dir}/log'    # Directory where log files are written"
        echo "                                        # Can be absolute or relative to PGDATA"
        echo "log_filename = 'postgresql-%a.log'      # Log file name pattern."
        echo "                                        # Can include strftime() escapes"
        echo "log_truncate_on_rotation = on           # If on, any existing log file of the same"
        echo "                                        # name as the new log file will be"
        echo "                                        # truncated rather than appended to. But"
        echo "                                        # such truncation only occurs on"
        echo "                                        # time-driven rotation, not on restarts"
        echo "                                        # or size-driven rotation. Default is"
        echo "                                        # off, meaning append to existing files"
        echo "                                        # in all cases."
        echo "log_rotation_age = 1d                   # Automatic rotation of logfiles will"
        echo "                                        # happen after that time.  0 to"
        echo "                                        # disable."
        echo "log_rotation_size = 0                   # Automatic rotation of logfiles will"
        echo "                                        # happen after that much log"
        echo "                                        # output.  0 to disable."
        echo ""
        echo "# These are relevant when logging to syslog:"
        echo "#syslog_facility = 'LOCAL0'"
        echo "#syslog_ident = 'postgres'"
        echo ""
        echo "#silent_mode = off                      # Run server silently."
        echo "                                        # DO NOT USE without syslog or"
        echo "                                        # logging_collector"
        echo "                                        # (change requires restart)"
        echo ""
        echo "# - When to Log -"
        echo ""

        if [ "$POSTGRESQL84_LOG_SETTINGS" == "yes" ]
        then
            echo "client_min_messages = $POSTGRESQL84_CLIENT_LOG_LEVEL"
            echo "log_min_messages = $POSTGRESQL84_SERVER_LOG_LEVEL"

            if [ "$POSTGRESQL84_LOG_VERBOSE" == "yes" ]
            then
                echo "log_error_verbosity = verbose"
            else
                echo "log_error_verbosity = default"
            fi

        else
            echo "#client_min_messages = notice        # Values, in order of decreasing detail:"
            echo "#log_min_messages = notice           # Values, in order of decreasing detail:"
            echo "#log_error_verbosity = default       # terse, default, or verbose messages"
        fi

        echo ""
        echo "#log_min_error_statement = panic        # Values in order of increasing severity:"
        echo "                                        #   debug5"
        echo "                                        #   debug4"
        echo "                                        #   debug3"
        echo "                                        #   debug2"
        echo "                                        #   debug1"
        echo "                                        #   info"
        echo "                                        #   notice"
        echo "                                        #   warning"
        echo "                                        #   error"
        echo "                                        #   panic(off)"
        echo ""
        echo "#log_min_duration_statement = -1        # -1 is disabled, 0 logs all statements"
        echo "                                        # and their durations, in milliseconds."
        echo ""
        echo ""
        echo "# - What to Log -"
        echo ""
        echo "#debug_print_parse = off"
        echo "#debug_print_rewritten = off"
        echo "#debug_print_plan = off"
        echo "#debug_pretty_print = off"
        echo "#log_checkpoints = off"
        echo "#log_connections = off"
        echo "#log_disconnections = off"
        echo "#log_duration = off"
        echo "#log_hostname = off"
        echo "log_line_prefix = '%t '               # Special values:"
        echo "                                        #   %u = user name"
        echo "                                        #   %d = database name"
        echo "                                        #   %r = remote host and port"
        echo "                                        #   %h = remote host"
        echo "                                        #   %p = PID"
        echo "                                        #   %t = timestamp (no milliseconds)"
        echo "                                        #   %m = timestamp with milliseconds"
        echo "                                        #   %i = command tag"
        echo "                                        #   %c = session id"
        echo "                                        #   %l = session line number"
        echo "                                        #   %s = session start timestamp"
        echo "                                        #   %v = virtual transaction ID"
        echo "                                        #   %x = transaction id"
        echo "                                        #   %q = stop here in non-session"
        echo "                                        #        processes"
        echo "                                        #   %% = '%'"
        echo "                                        # e.g. '<%u%%%d> '"

        if [ "$POSTGRESQL84_LOG_SETTINGS" == "yes" ]
        then
            if [ "$POSTGRESQL84_LOG_STATEMENTS" == "yes" ]
            then
                echo "log_statement = 'all'            # none, mod, ddl, all"
            else
                echo "log_statement = 'none'           # none, mod, ddl, all"
            fi
        else
            echo "#log_statement = 'none'              # none, mod, ddl, all"
        fi

        echo "#log_lock_waits = off                   # log lock waits >= deadlock_timeout"
        echo "#log_temp_files = -1                    # log temporary files equal or larger"
        echo "                                        # than the specified size in kilobytes;"
        echo "                                        # -1 disables, 0 logs all temp files"

        echo "#log_timezone = unknown                 # actually, defaults to TZ environment"
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# RUNTIME STATISTICS"
        echo "#---------------------------------------------------------------------------"
        echo ""
        echo "# - Statistics Monitoring -"
        echo ""
        echo "#log_parser_stats = off"
        echo "#log_planner_stats = off"
        echo "#log_executor_stats = off"
        echo "#log_statement_stats = off"
        echo ""
        echo "# - Query/Index Statistics Collector -"
        echo ""
        echo "#update_process_title = on"
        echo "#track_activities = on"
        echo "#track_counts = on"
        echo "#track_activity_query_size = 1024"
        echo "#stats_temp_directory = 'pg_stat_tmp'"
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# AUTOVACUUM PARAMETERS"
        echo "#---------------------------------------------------------------------------"
        echo ""
        if [ "$POSTGRESQL84_AUTOVACUUM" ==  "yes" ]
        then
            echo "autovacuum = on                         # enable autovacuum subprocess?"
        else
            echo "autovacuum = off                        # enable autovacuum subprocess?"
        fi
        echo "#log_autovacuum_min_duration = -1       # -1 disables, 0 logs all actions and"
        echo "                                        # their durations, > 0 logs only"
        echo "                                        # actions running at least that time."
        echo "#autovacuum_max_workers = 3             # max number of autovacuum subprocesses"
        echo "#autovacuum_naptime = 1min              # time between autovacuum runs"
        echo "#autovacuum_vacuum_threshold = 50       # min # of tuple updates before"
        echo "                                        # vacuum"
        echo "#autovacuum_analyze_threshold = 50      # min # of tuple updates before"
        echo "                                        # analyze"
        echo "#autovacuum_vacuum_scale_factor = 0.2   # fraction of rel size before"
        echo "                                        # vacuum"
        echo "#autovacuum_analyze_scale_factor = 0.1  # fraction of rel size before"
        echo "                                        # analyze"
        echo "#autovacuum_freeze_max_age = 200000000  # maximum XID age before forced vacuum"
        echo "                                        # (change requires restart)"
        echo "#autovacuum_vacuum_cost_delay = 20      # default vacuum cost delay for"
        echo "                                        # autovacuum, -1 means use"
        echo "                                        # vacuum_cost_delay"
        echo "#autovacuum_vacuum_cost_limit = -1      # default vacuum cost limit for"
        echo "                                        # autovacuum, -1 means use"
        echo "                                        # vacuum_cost_limit"
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# CLIENT CONNECTION DEFAULTS"
        echo "#---------------------------------------------------------------------------"
        echo ""
        echo "# - Statement Behavior -"
        echo ""
        echo "#search_path = \"'\$user\",public'      # schema names"
        echo "#default_tablespace = ''                # a tablespace name, '' uses"
        echo "                                        # the default"
        echo "#temp_tablespaces = ''                  # a list of tablespace names, '' uses"
        echo "                                        # only default tablespace"
        echo "#check_function_bodies = on"
        echo "#default_transaction_isolation = 'read committed'"
        echo "#default_transaction_read_only = off"
        echo "#session_replication_role = 'origin'"
        echo "#statement_timeout = 0                  # 0 is disabled"
        echo "#vacuum_freeze_min_age = 50000000"
        echo "#vacuum_freeze_table_age = 150000000"
        echo "#xmlbinary = 'base64'"
        echo "#xmloption = 'content'"
        echo ""
        echo "# - Locale and Formatting -"
        echo ""
        echo "datestyle = 'iso, mdy'"
        echo "#intervalstyle = 'postgres'"
        echo "#timezone = unknown                     # actually, defaults to TZ"
        echo "                                        # environment setting"
        echo "#timezone_abbreviations = 'Default'     # select the set of available timezone"
        echo "                                        # abbreviations. Currently, there are"
        echo "                                        #   Default"
        echo "                                        #   Australia"
        echo "                                        #   India"
        echo "                                        # However you can also create your own"
        echo "                                        # file in share/timezonesets/."
        echo "#extra_float_digits = 0                 # min -15, max 2"
        echo "#client_encoding = sql_ascii            # actually, defaults to database"
        echo "                                        # encoding"
        echo ""
        echo "# These settings are initialized by initdb -- they might be changed"
        echo ""
        echo "lc_messages = 'C'                       # locale for system error message"
        echo "                                        # strings"
        echo "lc_monetary = 'C'                       # locale for monetary formatting"
        echo "lc_numeric = 'C'                        # locale for number formatting"
        echo "lc_time = 'C'                           # locale for time formatting"
        echo ""
        echo "# default configuration for text search"
        echo "default_text_search_config = 'pg_catalog.english'"
        echo ""
        echo "# - Other Defaults -"
        echo ""
        echo "#dynamic_library_path = '\$libdir'"
        echo "#local_preload_libraries = ''"
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# LOCK MANAGEMENT"
        echo "#---------------------------------------------------------------------------"
        echo ""
        echo "#deadlock_timeout = 1s"
        echo "#max_locks_per_transaction = 64         # min 10"
        echo "                                        # (change requires restart)"
        echo "# Note: each lock table slot uses ~270 bytes of shared memory, and there are"
        echo "# max_locks_per_transaction * (max_connections + max_prepared_transactions)"
        echo "# lock table slots."
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# VERSION/PLATFORM COMPATIBILITY"
        echo "#---------------------------------------------------------------------------"
        echo ""
        echo "# - Previous Postgres Versions -"
        echo ""
        echo "#add_missing_from = off"
        echo "#array_nulls = on"
        echo "#backslash_quote = safe_encoding        # on, off, or safe_encoding"
        echo "#default_with_oids = off"
        echo "#escape_string_warning = on"
        echo "#standard_conforming_strings = off"
        echo "#regex_flavor = advanced                # advanced, extended, or basic"
        echo "#sql_inheritance = on"
        echo "#standard_conforming_strings = off"
        echo "#synchronize_seqscans = on"
        echo ""
        echo "# - Other Platforms & Clients -"
        echo ""
        echo "#transform_null_equals = off"
        echo ""
        echo "#---------------------------------------------------------------------------"
        echo "# CUSTOMIZED OPTIONS"
        echo "#---------------------------------------------------------------------------"
        echo ""
        echo "#custom_variable_classes = ''           # list of custom variable class names"
        echo ""
    } > ${data_dir}/postgresql.conf
    chown postgres.postgres ${data_dir}/postgresql.conf
    chmod 600 ${data_dir}/postgresql.conf
}


#------------------------------------------------------------------------------
# Main
#------------------------------------------------------------------------------

# make cron job
if [ "$START_POSTGRESQL84" = "yes" ] && \
   [ "$POSTGRESQL84_BACKUP_N" -gt "0" ]
then
    add_cron_job
else
    delete_cron_job
fi

#-----------------------------------------------------------------------------
# initialize database cluster in /var/lib/pgsql84
#-----------------------------------------------------------------------------

if [ "$START_POSTGRESQL84" = "yes" ]
then
    if [ ! -d "${data_dir}" ]
    then
        mecho -info "Creating database cluster in '${data_dir}'..."

        # start initdb
        mkdir -p "${data_dir}"
        chown postgres.postgres "${data_dir}"

        su postgres -c "${inst_dir}/bin/initdb --locale=C --encoding=LATIN9 -D ${data_dir}" > /tmp/$$ 2>&1

        # evaluate exit code
        if [ "$?" != "0" ]
        then
            cat /tmp/$$
        fi
        rm -f /tmp/$$

        # fix file permissions
        chown root.root ${inst_dir}
        chmod 0755 ${inst_dir}
    fi

    # write host access table
    write_hba_conf

    # write configuration
    write_postgresql_conf
fi

# create/remove start link
if [ "$START_POSTGRESQL84" = "yes" ]
then
    ln -sf /etc/init.d/${package} /etc/rc2.d/S45${package}
else
    if [ -f /etc/rc2.d/S45${package} ]
    then
        rm -f /etc/rc2.d/S45${package}
    fi
fi

# remove old logrotate file
rm -f /etc/logrotate.d/${package}

#----------------------------------------------------------------------------------------
# End
#----------------------------------------------------------------------------------------
exit 0
